@@ -4,24 +4,27 @@
 #'
 #' @param sequences (character) Returns all records containing matching marker 
 #' codes. Required.
-#' @param db (character) The database to match against, one of COX1, COX1_SPECIES,
-#' COX1_SPECIES_PUBLIC, OR COX1_L604bp. See Details for more information.
-#' @param response (logical) Note that response is the object that returns from the
-#' Curl call, useful for debugging, and getting detailed info on the API call.
-#' @param ... Further args passed on to httr::GET, main purpose being curl debugging
-#'
-#' @details Detailed description of options for the db parmeter:
+#' @param db (character) The database to match against, one of COX1, 
+#' COX1_SPECIES, COX1_SPECIES_PUBLIC, OR COX1_L604bp. See Details for 
+#' more information.
+#' @param response (logical) Note that response is the object that returns 
+#' from the Curl call, useful for debugging, and getting detailed info on 
+#' the API call.
+#' @param ... Further args passed on to \code{\link[httr]{GET}}, main purpose 
+#' being curl debugging
 #'
+#' @section db parmeter options:
 #' \itemize{
-#'  \item COX1 Every COI barcode record with a species level identification and
-#'  a minimum sequence length of 500bp. This includes many species represented by
-#'  only one or two specimens as well as  all species with interim taxonomy.
-#'  \item COX1_SPECIES Every COI barcode record on BOLD with a minimum sequence
+#'  \item COX1 Every COI barcode record on BOLD with a minimum sequence
 #'  length of 500bp (warning: unvalidated library and includes records without
 #'  species level identification). This includes many species represented by
 #'  only one or two specimens as well as all species with interim taxonomy. This
 #'  search only returns a list of the nearest matches and does not provide a
 #'  probability of placement to a taxon.
+#'  \item COX1_SPECIES Every COI barcode record with a species level 
+#'  identification and a minimum sequence length of 500bp. This includes 
+#'  many species represented by only one or two specimens as well as  all 
+#'  species with interim taxonomy.
 #'  \item COX1_SPECIES_PUBLIC All published COI records from BOLD and GenBank
 #'  with a minimum sequence length of 500bp. This library is a collection of
 #'  records from the published projects section of BOLD.
@@ -30,21 +33,21 @@
 #'  is intended for short sequence identification as it provides maximum overlap
 #'  with short reads from the barcode region of COI.
 #' }
+#' 
+#' @section Named outputs:
+#' To maintain names on the output list of data make sure to pass in a 
+#' named list to the \code{sequences} parameter. You can for example, 
+#' take a list of sequences, and use \code{\link{setNames}} to set names.
+#' 
 #' @return A data.frame with details for each specimen matched.
-#' @references \url{http://www.boldsystems.org/index.php/resources/api?type=idengine}
+#' @references 
+#' \url{http://www.boldsystems.org/index.php/resources/api?type=idengine}
+#' @seealso \code{\link{bold_identify_parents}}
 #' @examples \dontrun{
 #' seq <- sequences$seq1
-#' head(bold_identify(sequences=seq)[[1]])
+#' res <- bold_identify(sequences=seq)
+#' head(res[[1]])
 #' head(bold_identify(sequences=seq, db='COX1_SPECIES')[[1]])
-#' bold_identify(sequences=seq, response=TRUE)
-#'
-#' # Multiple sequences
-#' out <- bold_identify(sequences=c(sequences$seq2, sequences$seq3), db='COX1')
-#' lapply(out, head)
-#'
-#' # curl debugging
-#' library('httr')
-#' bold_identify(sequences=seq, response=TRUE, config=verbose())[[1]]
 #' }
 
 bold_identify <- function(sequences, db = 'COX1', response=FALSE, ...) {
@@ -61,15 +64,17 @@ bold_identify <- function(sequences, db = 'COX1', response=FALSE, ...) {
       tt <- content(out, "text", encoding = "UTF-8")
       xml <- xml2::read_xml(tt)
       nodes <- xml2::xml_find_all(xml, "//match")
-      toget <- c("ID","sequencedescription","database","citation","taxonomicidentification","similarity")
+      toget <- c("ID","sequencedescription","database",
+                 "citation","taxonomicidentification","similarity")
       outlist <- lapply(nodes, function(x){
         tmp2 <- vapply(toget, function(y) {
-          tmp <- xml2::xml_find_one(x, y)
+          tmp <- xml2::xml_find_first(x, y)
           setNames(xml2::xml_text(tmp), xml2::xml_name(tmp))
         }, "")
-        spectmp <- xml2::as_list(xml2::xml_find_one(x, "specimen"))
+        spectmp <- xml2::as_list(xml2::xml_find_first(x, "specimen"))
         spectmp <- unnest(spectmp)
-        names(spectmp) <- c('specimen_url','specimen_country','specimen_lat','specimen_lon')
+        names(spectmp) <- c('specimen_url','specimen_country',
+                            'specimen_lat','specimen_lon')
         spectmp[sapply(spectmp, is.null)] <- NA
         data.frame(c(tmp2, spectmp), stringsAsFactors = FALSE)
       })
