@@ -5,14 +5,17 @@
 #' @template otherargs
 #' @references \url{http://www.boldsystems.org/index.php/resources/api#combined}
 #'
-#' @param marker (character) Returns all records containing matching marker codes.
-#' @param format (character) One of xml or tsv (default). tsv format gives back a data.frame
-#' object. xml gives back parsed xml as a
-#' @param sepfasta (logical) If TRUE, the fasta data is separated into a list with names matching
-#' the processid's from the data frame
+#' @param marker (character) Returns all records containing matching marker 
+#' codes.
+#' @param format (character) One of xml or tsv (default). tsv format gives 
+#' back a data.frame object. xml gives back parsed xml as a
+#' @param sepfasta (logical) If \code{TRUE}, the fasta data is separated into 
+#' a list with names matching the processid's from the data frame.
+#' Default: \code{FALSE}
 #'
-#' @return Either a data.frame, parsed xml, a httr response object, or a list with length two
-#' (a data.frame w/o nucleotide data, and a list with nucleotide data)
+#' @return Either a data.frame, parsed xml, a httr response object, or a list 
+#' with length two (a data.frame w/o nucleotide data, and a list with 
+#' nucleotide data)
 #'
 #' @examples \dontrun{
 #' bold_seqspec(taxon='Osmia')
@@ -27,9 +30,12 @@
 #' 
 #' # records that match a geographic locality
 #' res <- bold_seqspec(taxon="Melanogrammus aeglefinus", geo="Canada")
+#' 
+#' # return only the longest sequence for each 
 #'
 #' ## curl debugging
-#' ### You can do many things, including get verbose output on the curl call, and set a timeout
+#' ### You can do many things, including get verbose output on the curl call, 
+#' ### and set a timeout
 #' library("httr")
 #' head(bold_seqspec(taxon='Osmia', config=verbose()))
 #' ## timeout
@@ -39,8 +45,8 @@
 #' }
 
 bold_seqspec <- function(taxon = NULL, ids = NULL, bin = NULL, container = NULL,
-  institutions = NULL, researchers = NULL, geo = NULL, marker = NULL, response=FALSE,
-  format = 'tsv', sepfasta=FALSE, ...) {
+  institutions = NULL, researchers = NULL, geo = NULL, marker = NULL, 
+  response=FALSE, format = 'tsv', sepfasta=FALSE, ...) {
   
   format <- match.arg(format, choices = c('xml','tsv'))
   args <- bc(list(taxon = pipeornull(taxon), geo = pipeornull(geo), 
@@ -56,11 +62,14 @@ bold_seqspec <- function(taxon = NULL, ids = NULL, bin = NULL, container = NULL,
   if (response) { 
     out
   } else {
-    tt <- rawToChar(content(out, encoding = "UTF-8"))
+    tt <- paste0(rawToChar(content(out, encoding = "UTF-8"), multiple = TRUE), 
+                 collapse = "")
     if (tt == "") return(NA)
-    temp <- switch(format,
-           xml = xml2::read_xml(tt),
-           tsv = read.delim(text = tt, header = TRUE, sep = "\t", stringsAsFactors = FALSE)
+    temp <- switch(
+      format,
+      xml = xml2::read_xml(tt),
+      tsv = read.delim(text = tt, header = TRUE, sep = "\t", 
+                       stringsAsFactors = FALSE)
     )
     if (!sepfasta) { 
       temp 
