@@ -1,6 +1,7 @@
 #' Search BOLD for taxonomy data by taxonomic name.
 #'
-#' @importFrom httr GET stop_for_status content parse_url build_url progress write_disk
+#' @importFrom httr GET stop_for_status content parse_url build_url 
+#' progress write_disk
 #' @importFrom assertthat assert_that
 #' @importFrom jsonlite fromJSON
 #' @importFrom reshape sort_df
@@ -9,10 +10,11 @@
 #' @param name (character) One or more scientific names. required.
 #' @param fuzzy (logical) Whether to use fuzzy search or not (default: FALSE).
 #' @template otherargs
-#' @references \url{http://boldsystems.org/index.php/resources/api?type=taxonomy#nameParameters}
-#' @details The \code{dataTypes} parameter is not supported in this function. If you want to
-#' use that parameter, get an ID from this function and pass it into \code{bold_tax_id}, and then
-#' use the \code{dataTypes} parameter.
+#' @references 
+#' \url{http://boldsystems.org/index.php/resources/api?type=taxonomy}
+#' @details The \code{dataTypes} parameter is not supported in this function. 
+#' If you want to use that parameter, get an ID from this function and pass 
+#' it into \code{bold_tax_id}, and then use the \code{dataTypes} parameter.
 #' @seealso \code{\link{bold_tax_id}}
 #' @examples \dontrun{
 #' bold_tax_name(name='Diplura')
@@ -45,6 +47,7 @@ bold_tax_name <- function(name, fuzzy = FALSE, response = FALSE, ...) {
   if (response) {
     tmp 
   } else {
-    do.call(rbind.fill, Map(process_response, x = tmp, y = name, z = FALSE, w = ""))
+    do.call(rbind.fill, 
+            Map(process_response, x = tmp, y = name, z = FALSE, w = ""))
   }
 }
