@@ -1,16 +1,16 @@
 # tests for bold_seq fxn in bold
 context("bold_seq")
 
-a <- bold_seq(taxon='Coelioxys')
-b <- bold_seq(bin='BOLD:AAA5125')
-c <- bold_seq(taxon='Coelioxys', response=TRUE)
-
-test_that("bold_seq returns the correct dimensions or values", {
+test_that("bold_seq returns the correct dimensions/classes", {
+  skip_on_cran()
+  
+  a <- bold_seq(taxon='Coelioxys')
+  b <- bold_seq(bin='BOLD:AAA5125')
+  c <- bold_seq(taxon='Coelioxys', response=TRUE)
+  
   expect_equal(c$status_code, 200)
   expect_equal(c$headers$`content-type`, "application/x-download")
-})
 
-test_that("bold_seq returns the correct classes", {
   expect_is(a, "list")
   expect_is(b, "list")
 
@@ -23,6 +23,8 @@ test_that("bold_seq returns the correct classes", {
 })
 
 test_that("bold_seq returns correct error when parameters empty or not given", {
+  skip_on_cran()
+  
   expect_error(bold_seq(taxon=''), "must provide a non-empty value")
   expect_error(bold_seq(), "must provide a non-empty value")
 })
